Function sig_bitmap::interpret
source · pub fn interpret(args: &SigBitmapArgs)Expand description
Displays the formatted string representaion of the specified type of signal bitmap for a given process. This function outputs an empty map if the process doesn’t exist or if there is an error interpreting the signal bitmap.
Arguments
args- A reference to anenumcontaining the process ID (PID) and the signal bitmap type.
Example
// Print the list of signals ignored by a process with PID: 42.
use sig_bitmap::{interpret, BitmapType, SigBitmapArgs};
let args: SigBitmapArgs = SigBitmapArgs{pid: 42, map: BitmapType::SigIgn};
interpret(&args);